Stan Math Library: doxygen/Eigen.dox File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces
doxygen/Eigen.dox File Reference

## Namespaces
| Eigen
| (Expert) Numerical traits for algorithmic differentiation variables.
| Eigen::internal
| (Expert) Product traits for algorithmic differentiation variables.

[ Stan Home Page ] © 2011–2016, Stan Development Team.